@@ -22,7 +22,7 @@ class Command(BaseCommand):
             "--processes", type=int, default=1, help="Number of processes (default: 1)"
         )
         parser.add_argument(
-            "--workers", type=int, default=2, help="Workers per process (default: 2)"
+            "--workers", type=int, default=1, help="Workers per process (default: 1)"
         )
         parser.add_argument(
             "--no-admin",
@@ -34,6 +34,18 @@ class Command(BaseCommand):
             action="store_true",
             help="Enable auto-reload on file changes (development mode)"
         )
+        parser.add_argument(
+            "--backlog",
+            type=int,
+            default=1024,
+            help="Socket listen backlog size (default: 1024)"
+        )
+        parser.add_argument(
+            "--keep-alive",
+            type=int,
+            default=None,
+            help="HTTP keep-alive timeout in seconds (default: OS setting)"
+        )
 
     def handle(self, *args, **options):
         processes = options['processes']
@@ -50,9 +62,6 @@ class Command(BaseCommand):
                 )
                 options['processes'] = 1
 
-            self.stdout.write(
-                self.style.SUCCESS("[django-bolt] 🔥 Development mode enabled (auto-reload on file changes)")
-            )
             self.run_with_autoreload(options)
         else:
             # Production mode (current logic)
@@ -75,11 +84,18 @@ class Command(BaseCommand):
             import sys
             sys.exit(1)
 
+        # Print dev mode message only once (in the main reloader process)
+        import os
+        if os.environ.get('RUN_MAIN') == 'true':
+            self.stdout.write(
+                self.style.SUCCESS("[django-bolt] 🔥 Development mode enabled (auto-reload on file changes)")
+            )
+
         # Use Django's autoreload system which is optimized
         # It only restarts the Python interpreter when necessary
         # and reuses the same process for faster reloads
         def run_server():
-            self.start_single_process(options)
+            self.start_single_process(options, dev_mode=True)
 
         autoreload.run_with_reloader(run_server)
 
@@ -133,7 +149,7 @@ class Command(BaseCommand):
         except KeyboardInterrupt:
             pass
     
-    def start_single_process(self, options, process_id=None):
+    def start_single_process(self, options, process_id=None, dev_mode=False):
         """Start a single process server"""
         # Setup Django logging once at server startup (one-shot, respects existing LOGGING)
         from django_bolt.logging.config import setup_django_logging
@@ -178,9 +194,9 @@ class Command(BaseCommand):
             merged_api._register_openapi_routes()
 
             if process_id is not None:
-                self.stdout.write(f"[django-bolt] Process {process_id}: OpenAPI docs enabled at {openapi_config.path}")
+                self.stdout.write(f"[django-bolt] Process {process_id}: OpenAPI docs enabled at http://{options['host']}:{options['port']}{openapi_config.path}")
             else:
-                self.stdout.write(self.style.SUCCESS(f"[django-bolt] OpenAPI docs enabled at {openapi_config.path}"))
+                self.stdout.write(self.style.SUCCESS(f"[django-bolt] OpenAPI docs enabled at http://{options['host']}:{options['port']}{openapi_config.path}"))
 
         # Register Django admin routes if not disabled
         # Admin is controlled solely by --no-admin command-line flag
@@ -242,10 +258,12 @@ class Command(BaseCommand):
         else:
             self.stdout.write(self.style.SUCCESS(f"[django-bolt] Starting server on http://{options['host']}:{options['port']}"))
             self.stdout.write(f"[django-bolt] Workers: {options['workers']}, Processes: {options['processes']}")
-            self.stdout.write(self.style.SUCCESS(f"[django-bolt] OpenAPI docs enabled at http://{options['host']}:{options['port']}/docs/"))
-        # Set environment variable for Rust to read worker count
+        # Set environment variable for Rust to read worker count, backlog, and keep-alive
         import os
         os.environ['DJANGO_BOLT_WORKERS'] = str(options['workers'])
+        os.environ['DJANGO_BOLT_BACKLOG'] = str(options['backlog'])
+        if options.get('keep_alive') is not None:
+            os.environ['DJANGO_BOLT_KEEP_ALIVE'] = str(options['keep_alive'])
 
         # Determine compression config (server-level in Actix)
         # Priority: Django setting > first API with compression config
@@ -348,25 +366,34 @@ class Command(BaseCommand):
 
     def import_api(self, dotted_path):
         """Import a BoltAPI instance from dotted path like 'myapp.api:api'"""
+        if ':' not in dotted_path:
+            return None
+
+        module_path, attr_name = dotted_path.split(':', 1)
+
         try:
-            if ':' not in dotted_path:
-                return None
-            
-            module_path, attr_name = dotted_path.split(':', 1)
             module = importlib.import_module(module_path)
-            
-            if not hasattr(module, attr_name):
+        except ModuleNotFoundError as e:
+            # Check if the error is for the target module itself (optional)
+            # or for a dependency within the module (fatal error)
+            if e.name == module_path or e.name == module_path.split('.')[0]:
+                # Target module doesn't exist - this is fine, api.py is optional
                 return None
-            
-            api = getattr(module, attr_name)
-            
-            # Verify it's a BoltAPI instance
-            if isinstance(api, BoltAPI):
-                return api
-            
-        except (ImportError, AttributeError, ValueError):
-            pass
-        
+            else:
+                # Module exists but has a missing dependency - let the original error bubble up
+                # This preserves the full traceback for debugging
+                raise
+
+        # If attribute doesn't exist, return None (not an error, just doesn't have that attr)
+        if not hasattr(module, attr_name):
+            return None
+
+        api = getattr(module, attr_name)
+
+        # Verify it's a BoltAPI instance
+        if isinstance(api, BoltAPI):
+            return api
+
         return None
 
     def merge_apis(self, apis):
