@@ -109,10 +109,14 @@ impl CorsConfig {
 
         // Compile origin regex patterns at startup
         config.origin_regexes = origin_regexes.clone();
-        config.compiled_origin_regexes = origin_regexes.iter()
+        config.compiled_origin_regexes = origin_regexes
+            .iter()
             .filter_map(|pattern| {
                 Regex::new(pattern).ok().or_else(|| {
-                    eprintln!("[django-bolt] Warning: Invalid route-level CORS origin regex pattern: {}", pattern);
+                    eprintln!(
+                        "[django-bolt] Warning: Invalid route-level CORS origin regex pattern: {}",
+                        pattern
+                    );
                     None
                 })
             })
@@ -171,6 +175,24 @@ impl Default for RateLimitConfig {
     }
 }
 
+/// Compression configuration parsed at startup
+#[derive(Debug, Clone)]
+pub struct CompressionConfig {
+    pub backend: String,        // "gzip", "brotli", "zstd"
+    pub minimum_size: usize,    // Minimum response size to compress (bytes)
+    pub gzip_fallback: bool,    // Fall back to gzip if backend not supported
+}
+
+impl Default for CompressionConfig {
+    fn default() -> Self {
+        CompressionConfig {
+            backend: "brotli".to_string(),
+            minimum_size: 500,
+            gzip_fallback: true,
+        }
+    }
+}
+
 /// Complete route metadata including middleware, auth, and guards
 #[derive(Debug, Clone)]
 pub struct RouteMetadata {
@@ -331,7 +353,10 @@ fn parse_cors_config(dict: &HashMap<String, Py<PyAny>>, py: Python) -> Option<Co
 }
 
 /// Parse rate limiting configuration from middleware dict
-fn parse_rate_limit_config(dict: &HashMap<String, Py<PyAny>>, py: Python) -> Option<RateLimitConfig> {
+fn parse_rate_limit_config(
+    dict: &HashMap<String, Py<PyAny>>,
+    py: Python,
+) -> Option<RateLimitConfig> {
     let mut config = RateLimitConfig::default();
 
     // Parse rps (required)
