@@ -15,8 +15,8 @@ use crate::request::PyRequest;
 use crate::router::{parse_query_string, Router};
 
 // Actix testing imports
-use actix_web::{test, web, App};
 use actix_web::dev::Service;
+use actix_web::{test, web, App};
 use bytes::Bytes;
 
 // Macro for conditional debug output - only enabled with DJANGO_BOLT_TEST_DEBUG env var
@@ -110,7 +110,8 @@ pub fn register_test_middleware_metadata(
                 Err(e) => {
                     test_debug!(
                         "Warning: Failed to parse metadata for handler {}: {}",
-                        handler_id, e
+                        handler_id,
+                        e
                     );
                 }
             }
@@ -219,7 +220,9 @@ pub fn handle_test_request_for(
     }
     test_debug!(
         "[test_state] matched handler_id={} path_params={:?} middleware_present={}",
-        handler_id, path_params, middleware_present
+        handler_id,
+        path_params,
+        middleware_present
     );
 
     // Parse query string
@@ -291,13 +294,11 @@ pub fn handle_test_request_for(
         }
     }
 
-    // Create context dict
-    let context = if middleware_present || auth_ctx.is_some() {
+    // Create context dict only if auth context is present
+    let context = if let Some(ref auth) = auth_ctx {
         let ctx_dict = PyDict::new(py);
         let ctx_py = ctx_dict.unbind();
-        if let Some(ref auth) = auth_ctx {
-            populate_auth_context(&ctx_py, auth, py);
-        }
+        populate_auth_context(&ctx_py, auth, py);
         Some(ctx_py)
     } else {
         None
@@ -333,15 +334,15 @@ pub fn handle_test_request_for(
 
     // Get or create event loop
     let loop_obj = if let Some(ev_obj) = event_loop_obj_opt {
-    test_debug!("[test_state] using stored event loop");
+        test_debug!("[test_state] using stored event loop");
         ev_obj.into_bound(py)
     } else {
-    test_debug!("[test_state] getting current event loop");
+        test_debug!("[test_state] getting current event loop");
         // Try to get current loop, or create new one
         match asyncio.call_method0("get_event_loop") {
             Ok(l) => l,
             Err(_) => {
-    test_debug!("[test_state] creating new event loop");
+                test_debug!("[test_state] creating new event loop");
                 let l = asyncio.call_method0("new_event_loop")?;
                 asyncio.call_method1("set_event_loop", (&l,))?;
                 // Store it for reuse
@@ -359,12 +360,20 @@ pub fn handle_test_request_for(
     let result_obj = result_obj.unbind();
 
     // Debug: check what type we got back
-    let type_name = result_obj.bind(py).get_type().name().map(|s| s.to_string()).unwrap_or_else(|_| "unknown".to_string());
+    let type_name = result_obj
+        .bind(py)
+        .get_type()
+        .name()
+        .map(|s| s.to_string())
+        .unwrap_or_else(|_| "unknown".to_string());
     test_debug!("[test_state] result type: {}", type_name);
 
     // Extract response (tuple fast-path)
     let tuple_result: Result<(u16, Vec<(String, String)>, Vec<u8>), _> = result_obj.extract(py);
-    test_debug!("[test_state] tuple extraction succeeded: {}", tuple_result.is_ok());
+    test_debug!(
+        "[test_state] tuple extraction succeeded: {}",
+        tuple_result.is_ok()
+    );
     if let Ok((status_code, resp_headers, body_bytes)) = tuple_result {
         // Filter out special headers
         let headers: Vec<(String, String)> = resp_headers
@@ -373,9 +382,13 @@ pub fn handle_test_request_for(
             .collect();
 
         // HEAD requests must have empty body per RFC 7231
-        let response_body = if method == "HEAD" { Vec::new() } else { body_bytes };
+        let response_body = if method == "HEAD" {
+            Vec::new()
+        } else {
+            body_bytes
+        };
 
-    test_debug!(
+        test_debug!(
             "[test_state] returning tuple status={} headers_len={} body_len={}",
             status_code,
             headers.len(),
@@ -396,21 +409,25 @@ pub fn handle_test_request_for(
     test_debug!("[test_state] is_streaming: {}", is_streaming);
 
     if is_streaming {
-    test_debug!("[test_state] handling streaming response");
+        test_debug!("[test_state] handling streaming response");
         let obj = result_obj.bind(py);
         let status_code: u16 = obj
             .getattr("status_code")
             .and_then(|v| v.extract())
             .unwrap_or(200);
-    test_debug!("[test_state] extracted status_code: {}", status_code);
+        test_debug!("[test_state] extracted status_code: {}", status_code);
 
         let mut resp_headers: Vec<(String, String)> = Vec::new();
-    test_debug!("[test_state] extracting headers...");
+        test_debug!("[test_state] extracting headers...");
         if let Ok(hobj) = obj.getattr("headers") {
-            let header_type = hobj.get_type().name().map(|s| s.to_string()).unwrap_or_else(|_| "unknown".to_string());
-    test_debug!("[test_state] got headers object, type: {}", header_type);
+            let header_type = hobj
+                .get_type()
+                .name()
+                .map(|s| s.to_string())
+                .unwrap_or_else(|_| "unknown".to_string());
+            test_debug!("[test_state] got headers object, type: {}", header_type);
             if let Ok(hdict) = hobj.downcast::<PyDict>() {
-    test_debug!("[test_state] headers is a dict");
+                test_debug!("[test_state] headers is a dict");
                 for (k, v) in hdict {
                     if let (Ok(ks), Ok(vs)) = (k.extract::<String>(), v.extract::<String>()) {
                         resp_headers.push((ks, vs));
@@ -418,7 +435,7 @@ pub fn handle_test_request_for(
                 }
             } else if hobj.hasattr("items").unwrap_or(false) {
                 // Try as dict-like with items() method
-    test_debug!("[test_state] headers has items() method");
+                test_debug!("[test_state] headers has items() method");
                 if let Ok(items_method) = hobj.call_method0("items") {
                     if let Ok(items_iter) = items_method.try_iter() {
                         for item in items_iter {
@@ -434,9 +451,15 @@ pub fn handle_test_request_for(
         }
 
         // Add media_type as content-type if provided
-        let is_sse = if let Ok(media_type) = obj.getattr("media_type").and_then(|v| v.extract::<String>()) {
+        let is_sse = if let Ok(media_type) = obj
+            .getattr("media_type")
+            .and_then(|v| v.extract::<String>())
+        {
             let is_event_stream = media_type.contains("event-stream");
-            if !resp_headers.iter().any(|(k, _)| k.eq_ignore_ascii_case("content-type")) {
+            if !resp_headers
+                .iter()
+                .any(|(k, _)| k.eq_ignore_ascii_case("content-type"))
+            {
                 resp_headers.push(("content-type".to_string(), media_type));
             }
             is_event_stream
@@ -446,10 +469,16 @@ pub fn handle_test_request_for(
 
         // Add SSE-friendly headers if this is an SSE response
         if is_sse {
-            if !resp_headers.iter().any(|(k, _)| k.eq_ignore_ascii_case("x-accel-buffering")) {
+            if !resp_headers
+                .iter()
+                .any(|(k, _)| k.eq_ignore_ascii_case("x-accel-buffering"))
+            {
                 resp_headers.push(("x-accel-buffering".to_string(), "no".to_string()));
             }
-            if !resp_headers.iter().any(|(k, _)| k.eq_ignore_ascii_case("cache-control")) {
+            if !resp_headers
+                .iter()
+                .any(|(k, _)| k.eq_ignore_ascii_case("cache-control"))
+            {
                 resp_headers.push(("cache-control".to_string(), "no-cache".to_string()));
             }
         }
@@ -458,7 +487,7 @@ pub fn handle_test_request_for(
         let mut content_obj = obj.getattr("content")?;
         // If content is callable (generator function), call it to get the generator
         if content_obj.is_callable() {
-    test_debug!("[test_state] content is callable, calling it...");
+            test_debug!("[test_state] content is callable, calling it...");
             content_obj = content_obj.call0()?;
         }
         let mut collected_body = Vec::new();
@@ -467,11 +496,13 @@ pub fn handle_test_request_for(
             // For async generators, we need to consume them with the event loop
             // Create a list from the async generator
             let _asyncio = py.import("asyncio")?;
-            let list_from_agen = |agen: &Bound<PyAny>, loop_obj: &Bound<PyAny>| -> PyResult<Vec<Vec<u8>>> {
-                let loop_ref = loop_obj.clone();
+            let list_from_agen =
+                |agen: &Bound<PyAny>, loop_obj: &Bound<PyAny>| -> PyResult<Vec<Vec<u8>>> {
+                    let loop_ref = loop_obj.clone();
 
-                // Use asyncio.run_until_complete to consume the async generator
-                let py_code = c_str!(r#"
+                    // Use asyncio.run_until_complete to consume the async generator
+                    let py_code = c_str!(
+                        r#"
 async def consume_agen(agen):
     chunks = []
     async for chunk in agen:
@@ -484,14 +515,15 @@ async def consume_agen(agen):
         elif isinstance(chunk, memoryview):
             chunks.append(bytes(chunk))
     return chunks
-"#);
-                let locals = pyo3::types::PyDict::new(py);
-                py.run(py_code, None, Some(&locals))?;
-                let consume_fn = locals.get_item("consume_agen")?.unwrap();
-                let coro = consume_fn.call1((agen,))?;
-                let result = loop_ref.call_method1("run_until_complete", (coro,))?;
-                result.extract()
-            };
+"#
+                    );
+                    let locals = pyo3::types::PyDict::new(py);
+                    py.run(py_code, None, Some(&locals))?;
+                    let consume_fn = locals.get_item("consume_agen")?.unwrap();
+                    let coro = consume_fn.call1((agen,))?;
+                    let result = loop_ref.call_method1("run_until_complete", (coro,))?;
+                    result.extract()
+                };
 
             match list_from_agen(&content_obj, &loop_obj) {
                 Ok(chunks) => {
@@ -500,9 +532,11 @@ async def consume_agen(agen):
                     }
                 }
                 Err(e) => {
-    test_debug!("[test_state] warning: failed to consume async generator: {}", e);
-                    collected_body =
-                        b"[error consuming async streaming content]".to_vec();
+                    test_debug!(
+                        "[test_state] warning: failed to consume async generator: {}",
+                        e
+                    );
+                    collected_body = b"[error consuming async streaming content]".to_vec();
                 }
             }
         } else if let Ok(iter) = content_obj.try_iter() {
@@ -518,7 +552,11 @@ async def consume_agen(agen):
         }
 
         // HEAD requests must have empty body per RFC 7231
-        let response_body = if method == "HEAD" { Vec::new() } else { collected_body };
+        let response_body = if method == "HEAD" {
+            Vec::new()
+        } else {
+            collected_body
+        };
         return Ok((status_code, resp_headers, response_body));
     }
 
@@ -538,15 +576,16 @@ pub fn handle_actix_http_request(
     query_string: Option<String>,
 ) -> PyResult<(u16, Vec<(String, String)>, Vec<u8>)> {
     // We need to run this in a tokio runtime since actix test functions are async
-    let runtime = tokio::runtime::Runtime::new()
-        .map_err(|e| pyo3::exceptions::PyRuntimeError::new_err(format!("Failed to create runtime: {}", e)))?;
-    
+    let runtime = tokio::runtime::Runtime::new().map_err(|e| {
+        pyo3::exceptions::PyRuntimeError::new_err(format!("Failed to create runtime: {}", e))
+    })?;
+
     runtime.block_on(async {
         // Verify test app exists
         let reg = registry();
-        let entry = reg
-            .get(&app_id)
-            .ok_or_else(|| pyo3::exceptions::PyRuntimeError::new_err(format!("Test app {} not found", app_id)))?;
+        let entry = reg.get(&app_id).ok_or_else(|| {
+            pyo3::exceptions::PyRuntimeError::new_err(format!("Test app {} not found", app_id))
+        })?;
         drop(entry);
 
         // Create custom handler that uses per-instance router via handle_test_request_for
@@ -572,7 +611,8 @@ pub fn handle_actix_http_request(
                 let body_bytes = body.to_vec();
 
                 // Get request origin for CORS
-                let request_origin = req.headers()
+                let request_origin = req
+                    .headers()
                     .get("origin")
                     .and_then(|v| v.to_str().ok())
                     .map(|s| s.to_string());
@@ -583,53 +623,80 @@ pub fn handle_actix_http_request(
                     && req.headers().contains_key("access-control-request-method");
 
                 // Get middleware config from route metadata and global CORS origins
-                let (cors_config, rate_limit_config, handler_id_opt, should_skip_cors, global_cors_origins) = Python::attach(|_py| -> (Option<crate::metadata::CorsConfig>, Option<crate::metadata::RateLimitConfig>, Option<usize>, bool, Vec<String>) {
-                    let Some(entry) = registry().get(&app_id) else {
-                        return (None, None, None, false, vec![]);
-                    };
-                    let app = entry.read();
+                let (
+                    cors_config,
+                    rate_limit_config,
+                    handler_id_opt,
+                    should_skip_cors,
+                    should_skip_compression,
+                    global_cors_origins,
+                ) = Python::attach(
+                    |_py| -> (
+                        Option<crate::metadata::CorsConfig>,
+                        Option<crate::metadata::RateLimitConfig>,
+                        Option<usize>,
+                        bool,
+                        bool,
+                        Vec<String>,
+                    ) {
+                        let Some(entry) = registry().get(&app_id) else {
+                            return (None, None, None, false, false, vec![]);
+                        };
+                        let app = entry.read();
 
-                    // Capture global CORS origins
-                    let global_origins = app.cors_allowed_origins.clone();
+                        // Capture global CORS origins
+                        let global_origins = app.cors_allowed_origins.clone();
 
-                    // For preflight, we need to check the actual route method, not OPTIONS
-                    let lookup_method = if is_preflight {
-                        // Get the requested method from Access-Control-Request-Method header
-                        req.headers()
-                            .get("access-control-request-method")
-                            .and_then(|v| v.to_str().ok())
-                            .map(|s| s.to_uppercase())
-                            .unwrap_or_else(|| method.clone())
-                    } else {
-                        method.clone()
-                    };
+                        // For preflight, we need to check the actual route method, not OPTIONS
+                        let lookup_method = if is_preflight {
+                            // Get the requested method from Access-Control-Request-Method header
+                            req.headers()
+                                .get("access-control-request-method")
+                                .and_then(|v| v.to_str().ok())
+                                .map(|s| s.to_uppercase())
+                                .unwrap_or_else(|| method.clone())
+                        } else {
+                            method.clone()
+                        };
 
-                    // Find the route to get handler_id
-                    if let Some((_route, _params, handler_id)) = app.router.find(&lookup_method, &path) {
-                        // Get route metadata
-                        if let Some(route_meta) = app.route_metadata.get(&handler_id) {
-                            // Check if CORS is skipped
-                            let skip_cors = route_meta.skip.contains("cors");
+                        // Find the route to get handler_id
+                        if let Some((_route, _params, handler_id)) =
+                            app.router.find(&lookup_method, &path)
+                        {
+                            // Get route metadata
+                            if let Some(route_meta) = app.route_metadata.get(&handler_id) {
+                                // Check if CORS is skipped
+                                let skip_cors = route_meta.skip.contains("cors");
+                                // Check if compression is skipped
+                                let skip_compression = route_meta.skip.contains("compression");
 
-                            // Use parsed Rust configs directly
-                            let cors_cfg = route_meta.cors_config.clone();
-                            let rate_cfg = route_meta.rate_limit_config.clone();
+                                // Use parsed Rust configs directly
+                                let cors_cfg = route_meta.cors_config.clone();
+                                let rate_cfg = route_meta.rate_limit_config.clone();
 
-                            return (cors_cfg, rate_cfg, Some(handler_id), skip_cors, global_origins);
+                                return (
+                                    cors_cfg,
+                                    rate_cfg,
+                                    Some(handler_id),
+                                    skip_cors,
+                                    skip_compression,
+                                    global_origins,
+                                );
+                            }
                         }
-                    }
-                    (None, None, None, false, global_origins)
-                });
+                        (None, None, None, false, false, global_origins)
+                    },
+                );
 
                 // Handle CORS preflight - MUST validate origin per RFC 6454
                 if is_preflight && !should_skip_cors {
                     if let Some(ref cors_cfg) = cors_config {
-                        use actix_web::HttpResponse;
                         use actix_web::http::header::{
                             ACCESS_CONTROL_ALLOW_CREDENTIALS, ACCESS_CONTROL_ALLOW_HEADERS,
                             ACCESS_CONTROL_ALLOW_METHODS, ACCESS_CONTROL_ALLOW_ORIGIN,
                             ACCESS_CONTROL_MAX_AGE, VARY,
                         };
+                        use actix_web::HttpResponse;
 
                         // Merge route-specific origins with global origins
                         let origins = if !cors_cfg.origins.is_empty() {
@@ -653,11 +720,23 @@ pub fn handle_actix_http_request(
                                 response.insert_header((ACCESS_CONTROL_ALLOW_ORIGIN, req_origin));
                                 response.insert_header((VARY, "Origin"));
                                 response.insert_header((ACCESS_CONTROL_ALLOW_CREDENTIALS, "true"));
-                                response.insert_header((ACCESS_CONTROL_ALLOW_METHODS, cors_cfg.methods.join(", ")));
-                                response.insert_header((ACCESS_CONTROL_ALLOW_HEADERS, cors_cfg.headers.join(", ")));
-                                response.insert_header((ACCESS_CONTROL_MAX_AGE, cors_cfg.max_age.to_string()));
+                                response.insert_header((
+                                    ACCESS_CONTROL_ALLOW_METHODS,
+                                    cors_cfg.methods.join(", "),
+                                ));
+                                response.insert_header((
+                                    ACCESS_CONTROL_ALLOW_HEADERS,
+                                    cors_cfg.headers.join(", "),
+                                ));
+                                response.insert_header((
+                                    ACCESS_CONTROL_MAX_AGE,
+                                    cors_cfg.max_age.to_string(),
+                                ));
                                 // CRITICAL: Add Vary headers for preflight (RFC 7234)
-                                response.insert_header((VARY, "Access-Control-Request-Method, Access-Control-Request-Headers"));
+                                response.insert_header((
+                                    VARY,
+                                    "Access-Control-Request-Method, Access-Control-Request-Headers",
+                                ));
                                 return Ok(response.finish());
                             }
                             // No origin header, reject
@@ -668,11 +747,23 @@ pub fn handle_actix_http_request(
                         if is_wildcard {
                             let mut response = HttpResponse::NoContent();
                             response.insert_header((ACCESS_CONTROL_ALLOW_ORIGIN, "*"));
-                            response.insert_header((ACCESS_CONTROL_ALLOW_METHODS, cors_cfg.methods.join(", ")));
-                            response.insert_header((ACCESS_CONTROL_ALLOW_HEADERS, cors_cfg.headers.join(", ")));
-                            response.insert_header((ACCESS_CONTROL_MAX_AGE, cors_cfg.max_age.to_string()));
+                            response.insert_header((
+                                ACCESS_CONTROL_ALLOW_METHODS,
+                                cors_cfg.methods.join(", "),
+                            ));
+                            response.insert_header((
+                                ACCESS_CONTROL_ALLOW_HEADERS,
+                                cors_cfg.headers.join(", "),
+                            ));
+                            response.insert_header((
+                                ACCESS_CONTROL_MAX_AGE,
+                                cors_cfg.max_age.to_string(),
+                            ));
                             // CRITICAL: Add Vary headers for preflight (RFC 7234)
-                            response.insert_header((VARY, "Access-Control-Request-Method, Access-Control-Request-Headers"));
+                            response.insert_header((
+                                VARY,
+                                "Access-Control-Request-Method, Access-Control-Request-Headers",
+                            ));
                             return Ok(response.finish());
                         }
 
@@ -699,29 +790,44 @@ pub fn handle_actix_http_request(
                         let mut response = HttpResponse::NoContent();
                         response.insert_header((ACCESS_CONTROL_ALLOW_ORIGIN, req_origin));
                         response.insert_header((VARY, "Origin"));
-                        response.insert_header((ACCESS_CONTROL_ALLOW_METHODS, cors_cfg.methods.join(", ")));
-                        response.insert_header((ACCESS_CONTROL_ALLOW_HEADERS, cors_cfg.headers.join(", ")));
-                        response.insert_header((ACCESS_CONTROL_MAX_AGE, cors_cfg.max_age.to_string()));
+                        response.insert_header((
+                            ACCESS_CONTROL_ALLOW_METHODS,
+                            cors_cfg.methods.join(", "),
+                        ));
+                        response.insert_header((
+                            ACCESS_CONTROL_ALLOW_HEADERS,
+                            cors_cfg.headers.join(", "),
+                        ));
+                        response
+                            .insert_header((ACCESS_CONTROL_MAX_AGE, cors_cfg.max_age.to_string()));
 
                         if cors_cfg.credentials {
                             response.insert_header((ACCESS_CONTROL_ALLOW_CREDENTIALS, "true"));
                         }
 
                         // CRITICAL: Add Vary headers for preflight per RFC 7234
-                        response.insert_header((VARY, "Access-Control-Request-Method, Access-Control-Request-Headers"));
+                        response.insert_header((
+                            VARY,
+                            "Access-Control-Request-Method, Access-Control-Request-Headers",
+                        ));
 
                         return Ok(response.finish());
                     }
                 }
 
                 // Check rate limiting
-                if let (Some(handler_id), Some(rate_cfg)) = (handler_id_opt, rate_limit_config.as_ref()) {
+                if let (Some(handler_id), Some(rate_cfg)) =
+                    (handler_id_opt, rate_limit_config.as_ref())
+                {
                     use crate::middleware::rate_limit::check_rate_limit;
                     // Convert headers to AHashMap
-                    let header_map: ahash::AHashMap<String, String> = headers.iter()
+                    let header_map: ahash::AHashMap<String, String> = headers
+                        .iter()
                         .map(|(k, v)| (k.to_lowercase(), v.clone()))
                         .collect();
-                    if let Some(response) = check_rate_limit(handler_id, &header_map, None, rate_cfg) {
+                    if let Some(response) =
+                        check_rate_limit(handler_id, &header_map, None, rate_cfg)
+                    {
                         return Ok(response);
                     }
                 }
@@ -740,10 +846,15 @@ pub fn handle_actix_http_request(
                 });
 
                 match result {
-                    Ok((status_code, resp_headers, resp_body)) => {
+                    Ok((status_code, mut resp_headers, resp_body)) => {
+                        // Add Content-Encoding: identity header if compression should be skipped
+                        if should_skip_compression {
+                            resp_headers.push(("content-encoding".to_string(), "identity".to_string()));
+                        }
+
                         let mut response = actix_web::HttpResponse::build(
                             actix_web::http::StatusCode::from_u16(status_code)
-                                .unwrap_or(actix_web::http::StatusCode::OK)
+                                .unwrap_or(actix_web::http::StatusCode::OK),
                         );
                         for (name, value) in &resp_headers {
                             response.insert_header((name.as_str(), value.as_str()));
@@ -782,7 +893,8 @@ pub fn handle_actix_http_request(
                                     if origins.iter().any(|o| o == req_origin) {
                                         req_origin
                                     } else {
-                                        return Ok::<_, actix_web::Error>(http_response); // Origin not allowed
+                                        return Ok::<_, actix_web::Error>(http_response);
+                                        // Origin not allowed
                                     }
                                 } else {
                                     origins.first().map(|s| s.as_str()).unwrap_or("*")
@@ -795,10 +907,9 @@ pub fn handle_actix_http_request(
                                 );
 
                                 if origin_to_use != "*" {
-                                    http_response.headers_mut().insert(
-                                        VARY,
-                                        "Origin".parse().unwrap(),
-                                    );
+                                    http_response
+                                        .headers_mut()
+                                        .insert(VARY, "Origin".parse().unwrap());
                                 }
 
                                 if cors_cfg.credentials {
@@ -819,10 +930,8 @@ pub fn handle_actix_http_request(
 
                         Ok::<_, actix_web::Error>(http_response)
                     }
-                    Err(e) => {
-                        Ok(actix_web::HttpResponse::InternalServerError()
-                            .body(format!("Handler error: {}", e)))
-                    }
+                    Err(e) => Ok(actix_web::HttpResponse::InternalServerError()
+                        .body(format!("Handler error: {}", e))),
                 }
             }
         };
@@ -830,22 +939,23 @@ pub fn handle_actix_http_request(
         // Create Actix test service with middleware
         let app = test::init_service(
             App::new()
-                .wrap(actix_web::middleware::Compress::default())
+                .wrap(crate::middleware::compression::CompressionMiddleware::new())
                 // CORS handled in handler closure (preflight + response headers)
                 // Rate limiting handled in handler closure (per-route state)
-                .default_service(web::route().to(handler))
-        ).await;
-        
+                .default_service(web::route().to(handler)),
+        )
+        .await;
+
         // Build full URI
         let uri = if let Some(qs) = query_string {
             format!("{}?{}", path, qs)
         } else {
             path
         };
-        
+
         // Create test request
         let mut req = test::TestRequest::with_uri(&uri);
-        
+
         // Set method
         req = match method.to_uppercase().as_str() {
             "GET" => req.method(actix_web::http::Method::GET),
@@ -857,33 +967,34 @@ pub fn handle_actix_http_request(
             "HEAD" => req.method(actix_web::http::Method::HEAD),
             _ => req.method(actix_web::http::Method::GET),
         };
-        
+
         // Set headers
         for (name, value) in headers {
             req = req.insert_header((name, value));
         }
-        
+
         // Set body
         if !body.is_empty() {
             req = req.set_payload(Bytes::from(body));
         }
-        
+
         // Call service
         let request = req.to_request();
-        let response = app.call(request).await
-            .map_err(|e| pyo3::exceptions::PyRuntimeError::new_err(format!("Service call failed: {}", e)))?;
-        
+        let response = app.call(request).await.map_err(|e| {
+            pyo3::exceptions::PyRuntimeError::new_err(format!("Service call failed: {}", e))
+        })?;
+
         // Extract response
         let status = response.status().as_u16();
-        
+
         let resp_headers: Vec<(String, String)> = response
             .headers()
             .iter()
             .map(|(k, v)| (k.as_str().to_string(), v.to_str().unwrap_or("").to_string()))
             .collect();
-        
+
         let resp_body = test::read_body(response).await.to_vec();
-        
+
         Ok((status, resp_headers, resp_body))
     })
 }
